package bus

import (
	"context"
	"pay/db"
	"pay/db/repo"
	"pay/utils"

	"github.com/nats-io/nats.go"
	"go.mongodb.org/mongo-driver/bson"
	"infish.cn/comm"
)

// id， 支付数量 * price,userId ==> order --> createqr/refound... --> 为用户授权服务

// 根据project获取列表，sort排序-->选择数量支付方式-->生成订单-->成功

// 根据项目类型 获取支付列表
// query := map[string]interface{}{"project":"queenshow"}
func PayProjectList() *comm.NatsMsgReplyer {

	utils.ConsoleFormat(comm.CommPayProjectListApi)
	return &comm.NatsMsgReplyer{
		Subject: comm.CommPayProjectListApi,
		Entity:  func() interface{} { return map[string]interface{}{} },
		Cb2: func(_ *nats.Msg, entity interface{}) (interface{}, error) {
			query := entity.(map[string]interface{})
			ctx := context.Background()
			res, err := getPayProjects(ctx, query)
			return res, err
		},
	}
}

func getPayProjects(ctx context.Context, query map[string]interface{}) (projects []*comm.Pay, err error) {
	err = repo.RepoSeachDocs(&repo.RepoSession{Ctx: ctx, Client: db.GMongoDb}, &repo.DocSearchOptions{
		CollectName: repo.CollectionPay,
		Query:       query,
		Sort:        bson.D{bson.E{Key: "sort", Value: 1}, bson.E{Key: "createTime", Value: -1}},
	}, &projects)
	return
}

// query := map[string]interface{}{"_id":"xxx"}
func PayProjectDetail() *comm.NatsMsgReplyer {

	utils.ConsoleFormat(comm.CommPayProjectDetailApi)
	return &comm.NatsMsgReplyer{
		Subject: comm.CommPayProjectDetailApi,
		Entity:  func() interface{} { return map[string]interface{}{} },
		Cb2: func(_ *nats.Msg, entity interface{}) (interface{}, error) {
			query := entity.(map[string]interface{})
			ctx := context.Background()
			res, err := getPayProject(ctx, query)
			return res, err
		},
	}
}

func getPayProject(ctx context.Context, query map[string]interface{}) (project *comm.Pay, err error) {
	_, err = repo.RepoSeachDoc(&repo.RepoSession{Ctx: ctx, Client: db.GMongoDb}, &repo.DocSearchOptions{
		CollectName: repo.CollectionPay,
		Query:       query,
	}, &project)
	return
}
