package bus

import (
	"context"
	"pay/db/model"
	"pay/utils"

	"github.com/nats-io/nats.go"
	"infish.cn/comm"
)

type SinglePay struct{}

// 创建二维码
func (s *SinglePay) CreateQr() *comm.NatsMsgReplyer {
	utils.ConsoleFormat(comm.CommPaySku3dCreateQrApi)

	return &comm.NatsMsgReplyer{
		Subject: comm.CommPaySku3dCreateQrApi,
		Entity:  func() interface{} { return &model.OrderMsg{} },
		Cb2: func(msg *nats.Msg, entity interface{}) (interface{}, error) {
			m := entity.(*model.OrderMsg)
			pay := PayMod(*m.PayMode, SINGLE)
			ctx := context.Background()
			res, err := pay.Pay(ctx, m)
			return res, err
		},
	}
}

// 关闭订单应答
func (s *SinglePay) CloseOrder() *comm.NatsMsgReplyer {
	utils.ConsoleFormat("comm.pay.singlePay.closeOrder")

	return &comm.NatsMsgReplyer{
		Subject: "comm.pay.singlePay.closeOrder",
		Entity:  func() interface{} { return &model.OrderMsg{} },
		Cb2: func(msg *nats.Msg, entity interface{}) (interface{}, error) {
			m := entity.(*model.OrderMsg)
			pay := PayMod(*m.PayMode, SINGLE)
			ctx := context.Background()
			flag, err := pay.Close(ctx, m)
			return flag, err
		},
	}
}

// 退款
func (s *SinglePay) Refund() *comm.NatsMsgReplyer {
	utils.ConsoleFormat("comm.pay.singlePay.refund")

	return &comm.NatsMsgReplyer{
		Subject: "comm.pay.singlePay.refund",
		Entity:  func() interface{} { return &model.ReFund{} },
		Cb2: func(msg *nats.Msg, entity interface{}) (interface{}, error) {
			refund := entity.(*model.ReFund)
			// ???适配缺失退款理由
			if refund.Reason == "" {
				refund.Reason = "默认退款"
			}
			pay := PayMod(int(*refund.PayMode), SINGLE)
			ctx := context.Background()
			flag, err := pay.ReFundPay(ctx, refund)
			return flag, err
		},
	}
}

// 退款查询
func (s *SinglePay) RefundQuery() *comm.NatsMsgReplyer {
	utils.ConsoleFormat("comm.pay.singlePay.refundQuery")

	return &comm.NatsMsgReplyer{
		Subject: "comm.pay.singlePay.refundQuery",
		Entity:  func() interface{} { return &model.ReFund{} },
		Cb2: func(msg *nats.Msg, entity interface{}) (interface{}, error) {
			m := entity.(*model.ReFund)
			pay := PayMod(int(*m.PayMode), SINGLE)
			ctx := context.Background()
			status, err := pay.ReFundQuery(ctx, m)
			return status, err
		},
	}
}
